pygeai.tests.snippets.lab package
=================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pygeai.tests.snippets.lab.agents
   pygeai.tests.snippets.lab.processes
   pygeai.tests.snippets.lab.samples
   pygeai.tests.snippets.lab.strategies
   pygeai.tests.snippets.lab.tools
   pygeai.tests.snippets.lab.use_cases

Submodules
----------

pygeai.tests.snippets.lab.agentic\_flow\_example\_1 module
----------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.agentic_flow_example_1
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.agentic\_flow\_example\_2 module
----------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.agentic_flow_example_2
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.agentic\_flow\_example\_3 module
----------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.agentic_flow_example_3
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.agentic\_flow\_example\_4 module
----------------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.agentic_flow_example_4
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.assistant\_to\_agent module
-----------------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.assistant_to_agent
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.crud\_ui module
-----------------------------------------

.. automodule:: pygeai.tests.snippets.lab.crud_ui
   :members:
   :show-inheritance:
   :undoc-members:

pygeai.tests.snippets.lab.runner\_1 module
------------------------------------------

.. automodule:: pygeai.tests.snippets.lab.runner_1
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: pygeai.tests.snippets.lab
   :members:
   :show-inheritance:
   :undoc-members:
